@@ -1,5 +1,5 @@
 """ Init file for tgfp_lib module """
-from tgfp import TGFP, TGFPGame, TGFPTeam, TGFPPick, TGFPPlayer, TGFPClan
+from .tgfp import TGFP, TGFPGame, TGFPTeam, TGFPPick, TGFPPlayer, TGFPClan
 
 __all__ = [
     'TGFP',
